# dispy: Admin Node

IP Address |
Name |
CPUs Managed by dispy |
Available CPU | Unknown
Available Memory | Unknown
Available Swap Space | Unknown
Available Disk Space | Unknown
Clients Done |
Jobs Done |
CPU Time Used Sec |

Poll Interval Seconds : | Now |
Service Start Time : | Now |
Service Stop Time : | Now |
Service End Time : | Now |
# of CPUs to Use : | All |
# of Clients to Run : (and Quit) |  |
Name or IP of Node to Show : |  |